@@ -4,7 +4,7 @@
  * Created Date: 29/05/2021
  * Author: Shun Suzuki
  * -----
- * Last Modified: 02/10/2021
+ * Last Modified: 24/11/2021
  * Modified By: Shun Suzuki (suzuki@hapis.k.u-tokyo.ac.jp)
  * -----
  * Copyright (c) 2021 Hapis Lab. All rights reserved.
@@ -18,9 +18,9 @@ use crate::{
 };
 use anyhow::Result;
 use autd3_core::{
-    gain::Gain,
+    gain::{Gain, GainData},
     geometry::{Geometry, Vector3},
-    hardware_defined::{DataArray, NUM_TRANS_IN_UNIT},
+    hardware_defined::NUM_TRANS_IN_UNIT,
 };
 use autd3_traits::Gain;
 use nalgebra::ComplexField;
@@ -30,7 +30,7 @@ use std::marker::PhantomData;
 /// * Long, Benjamin, et al. "Rendering volumetric haptic shapes in mid-air using ultrasound." ACM Transactions on Graphics (TOG) 33.6 (2014): 1-10.
 #[derive(Gain)]
 pub struct Evd<B: Backend> {
-    data: Vec<DataArray>,
+    data: Vec<GainData>,
     built: bool,
     foci: Vec<Vector3>,
     amps: Vec<f64>,
@@ -131,8 +131,6 @@ impl<B: Backend> Evd<B> {
 
         let max_coeff = B::max_coefficient_c(&gtf);
         set_from_complex_drive(&mut self.data, &gtf, self.normalize, max_coeff);
-
-        self.built = true;
         Ok(())
     }
 }
