@@ -4,7 +4,7 @@
  * Created Date: 28/05/2021
  * Author: Shun Suzuki
  * -----
- * Last Modified: 02/10/2021
+ * Last Modified: 24/11/2021
  * Modified By: Shun Suzuki (suzuki@hapis.k.u-tokyo.ac.jp)
  * -----
  * Copyright (c) 2021 Hapis Lab. All rights reserved.
@@ -17,9 +17,9 @@ use crate::{
 };
 use anyhow::Result;
 use autd3_core::{
-    gain::Gain,
+    gain::{Gain, GainData},
     geometry::{Geometry, Vector3},
-    hardware_defined::{DataArray, NUM_TRANS_IN_UNIT},
+    hardware_defined::NUM_TRANS_IN_UNIT,
 };
 use autd3_traits::Gain;
 use nalgebra::ComplexField;
@@ -30,7 +30,7 @@ use std::{marker::PhantomData, ops::MulAssign};
 /// * Inoue, Seki, Yasutoshi Makino, and Hiroyuki Shinoda. "Active touch perception produced by airborne ultrasonic haptic hologram." 2015 IEEE World Haptics Conference (WHC). IEEE, 2015.
 #[derive(Gain)]
 pub struct Sdp<B: Backend> {
-    data: Vec<DataArray>,
+    data: Vec<GainData>,
     built: bool,
     foci: Vec<Vector3>,
     amps: Vec<f64>,
@@ -176,8 +176,6 @@ impl<B: Backend> Sdp<B> {
 
         let max_coeff = B::max_coefficient_c(&q);
         set_from_complex_drive(&mut self.data, &q, self.normalize, max_coeff);
-
-        self.built = true;
         Ok(())
     }
 }
