@@ -4,7 +4,7 @@
  * Created Date: 29/05/2021
  * Author: Shun Suzuki
  * -----
- * Last Modified: 02/10/2021
+ * Last Modified: 24/11/2021
  * Modified By: Shun Suzuki (suzuki@hapis.k.u-tokyo.ac.jp)
  * -----
  * Copyright (c) 2021 Hapis Lab. All rights reserved.
@@ -17,20 +17,21 @@ use crate::{
 };
 use anyhow::Result;
 use autd3_core::{
-    gain::Gain,
+    gain::{Gain, GainData},
     geometry::{Geometry, Vector3},
-    hardware_defined::{DataArray, NUM_TRANS_IN_UNIT},
+    hardware_defined::NUM_TRANS_IN_UNIT,
 };
 use autd3_traits::Gain;
 use nalgebra::ComplexField;
 use std::marker::PhantomData;
+
 /// References
 /// * K.Levenberg, “A method for the solution of certain non-linear problems in least squares,” Quarterly of applied mathematics, vol.2, no.2, pp.164–168, 1944.
 /// * D.W.Marquardt, “An algorithm for least-squares estimation of non-linear parameters,” Journal of the society for Industrial and AppliedMathematics, vol.11, no.2, pp.431–441, 1963.
 /// * K.Madsen, H.Nielsen, and O.Tingleff, “Methods for non-linear least squares problems (2nd ed.),” 2004.
 #[derive(Gain)]
 pub struct Lm<B: Backend> {
-    data: Vec<DataArray>,
+    data: Vec<GainData>,
     built: bool,
     foci: Vec<Vector3>,
     amps: Vec<f64>,
@@ -219,17 +220,14 @@ impl<B: Backend> Lm<B> {
         let mut trans_idx = 0;
         for j in 0..n {
             let duty = 0xFF;
-            let phase = x[j];
-            let phase = autd3_core::utils::to_phase(phase);
-            self.data[dev_idx][trans_idx] = autd3_core::utils::pack_to_u16(duty, phase);
+            self.data[dev_idx][trans_idx].duty = duty;
+            self.data[dev_idx][trans_idx].phase = autd3_core::utils::to_phase(x[j]);
             trans_idx += 1;
             if trans_idx == NUM_TRANS_IN_UNIT {
                 dev_idx += 1;
                 trans_idx = 0;
             }
         }
-
-        self.built = true;
         Ok(())
     }
 }
